@@ -421,13 +421,13 @@ class RestAPI(object):
 		return r3sponse.success_response("Successfully synchronized the users.", log_level=log_level)
 
 		#
-	def set_email_permission(self uid, permission=True):
+	def set_email_permission(self, uid, permission=True):
 		
 		# load user data.
 		reference = f"users/{uid}"
 		response = self.firebase.firestore.load(reference) 
 		if not r3sponse.success(response): return response
-		data = response["data"]
+		data = response["document"]
 
 		# edit data.
 		data["email_permission"] = permission
@@ -507,7 +507,7 @@ class RestAPI(object):
 		reference = f"users/{uid}"
 		response = self.firebase.firestore.load(reference) 
 		if not r3sponse.success(response): return response
-		data = response["data"]
+		data = response["document"]
 
 		# edit data.
 		data["requests"] = -1*requests
@@ -527,7 +527,7 @@ class RestAPI(object):
 		reference = f"users/{uid}"
 		response = self.firebase.firestore.load(reference) 
 		if not r3sponse.success(response): return response
-		data = response["data"]
+		data = response["document"]
 
 		# edit data.
 		data["requests"] = 0
@@ -580,8 +580,7 @@ class RestAPI(object):
 			edits += 1
 
 		# test signed up stamp.
-		try: data["signed_up"]
-		except KeyError: 
+		if data["signed_up"] == None:
 			data["signed_up"] = Formats.Date().date
 			edits += 1
 
